import sys
import typing


def use_shading_nodes():
    ''' Enable nodes on a material, world or lamp :file: addons/cycles/ui.py <https://developer.blender.org/diffusion/BA//addons/cycles/ui.py> _:813

    '''

    pass
