import sys
import typing


def cancel_stroke():
    ''' Cancel the current sketch stroke

    '''

    pass


def convert():
    ''' Convert the selected sketch strokes to bone chains

    '''

    pass


def delete():
    ''' Delete a sketch stroke

    '''

    pass


def draw_preview(snap: bool = False):
    ''' Draw preview of current sketch stroke (internal use)

    :param snap: Snap
    :type snap: bool
    '''

    pass


def draw_stroke(snap: bool = False):
    ''' Start to draw a sketch stroke

    :param snap: Snap
    :type snap: bool
    '''

    pass


def finish_stroke():
    ''' End and keep the current sketch stroke

    '''

    pass


def gesture(snap: bool = False):
    ''' Start to draw a gesture stroke

    :param snap: Snap
    :type snap: bool
    '''

    pass


def select():
    ''' Select a sketch stroke

    '''

    pass
